Package: SSVS
Title: Functions for Stochastic Search Variable Selection (SSVS)
Version: 2.2.0
Authors@R: c(person(given="Sierra",
         family="Bainter",
         role=c("cre", "aut"),
         email="sbainter@miami.edu",
         comment=c(ORCID="0000-0001-7461-0803")),
  person(given="Thomas",
         family="McCauley",
         role=c("aut"),
         email="thomasgranvillemccauley@gmail.com"),
  person(given="Mahmoud",
         family="Fahmy",
         role=c("aut"),
         email="mahmoud.m.fahm@gmail.com"),
  person("Dean", "Attali", 
         role = "aut",
         email = "daattali@gmail.com", 
         comment= c(ORCID="0000-0002-5645-3493")))
Description: Functions for performing stochastic search variable selection (SSVS) 
    for binary and continuous outcomes and visualizing the results. 
    SSVS is a Bayesian variable selection method used to estimate the probability 
    that individual predictors should be included in a regression model. 
    Using MCMC estimation, the method samples thousands of regression models 
    in order to characterize the model uncertainty regarding both the predictor 
    set and the regression parameters. For details see Bainter, McCauley, Wager, 
    and Losin (2020) Improving practices for selecting a subset of important 
    predictors in psychology: An application to predicting pain, Advances in 
    Methods and Practices in Psychological Science 3(1), 66-80 
    <DOI:10.1177/2515245919885617>.
URL: https://github.com/sabainter/SSVS
BugReports: https://github.com/sabainter/SSVS/issues
Depends: R (>= 4.5.0)
Imports: bayestestR, BoomSpikeSlab, checkmate, ggplot2, graphics,
        rlang, stats, dplyr, magrittr, gridExtra
Suggests: AER, bslib, foreign, glue, knitr, mice, psych, reactable,
        readxl, rmarkdown, scales, shiny, shinyjs, shinyWidgets,
        testthat (>= 3.0.0), tools, utils
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-09 20:44:30 UTC; sbainter
Author: Sierra Bainter [cre, aut] (ORCID:
    <https://orcid.org/0000-0001-7461-0803>),
  Thomas McCauley [aut],
  Mahmoud Fahmy [aut],
  Dean Attali [aut] (ORCID: <https://orcid.org/0000-0002-5645-3493>)
Maintainer: Sierra Bainter <sbainter@miami.edu>
Repository: CRAN
Date/Publication: 2026-04-09 21:00:09 UTC
Built: R 4.5.2; ; 2026-04-15 05:10:28 UTC; unix

# Generated by roxygen2: do not edit by hand

S3method(plot,ssvs)
S3method(plot,ssvs_mi)
S3method(print,ssvs_mi_summary)
S3method(print,ssvs_summary)
S3method(summary,ssvs)
S3method(summary,ssvs_mi)
export("%>%")
export(launch)
export(ssvs)
export(ssvs_mi)
importFrom(magrittr,"%>%")
importFrom(rlang,.data)

<!-- README.md is generated from README.Rmd. Please edit that file -->

# SSVS <img src="man/figures/logo.png" align="right" width="120"/>

<!-- badges: start -->

[![R-CMD-check](https://github.com/sabainter/SSVS/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/sabainter/SSVS/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

The goal of {SSVS} is to provide functions for performing stochastic
search variable selection (SSVS) for binary and continuous outcomes and
visualizing the results. SSVS is a Bayesian variable selection method
used to estimate the probability that individual predictors should be
included in a regression model. Using MCMC estimation, the method
samples thousands of regression models in order to characterize the
model uncertainty regarding both the predictor set and the regression
parameters.

## Installation

You can install the development version of {SSVS} from
[GitHub](https://github.com/) with:

``` r
# install.packages("remotes")
remotes::install_github("sabainter/SSVS")
```

## Example 1 - continuous response variable

Consider a simple example using SSVS on the `mtcars` dataset to predict
quarter mile times. We first specify our response variable (“qsec”),
then choose our predictors and run the `ssvs()` function.

``` r
library(SSVS)
set.seed(1000)
outcome <- 'qsec'
predictors <- c('cyl', 'disp', 'hp', 'drat', 'wt',
 'vs', 'am', 'gear', 'carb','mpg')

results <- ssvs(data = mtcars, x = predictors, y = outcome, prior.probs = .5, progress = FALSE)
```

The results can be summarized and printed using the `summary()`
function. This will display the MIP for each predictor, the average
coefficients including and excluding zeros, and credible intervals for
each coefficient.

``` r
summary_results <- summary(results, interval = 0.9, ordered = TRUE)
```

| Variable |  MIP   | Avg Beta | Avg Nonzero Beta | Lower CI (90%) | Upper CI (90%) |
|:---------|:------:|:--------:|:----------------:|:--------------:|:--------------:|
| wt       | 0.8610 |  1.0867  |      1.2621      |     0.0000     |     1.9848     |
| vs       | 0.7811 |  0.6758  |      0.8652      |     0.0000     |     1.2105     |
| hp       | 0.5624 | -0.5301  |     -0.9425      |    -1.3503     |     0.0000     |
| disp     | 0.4148 | -0.4669  |     -1.1257      |    -1.8466     |     0.0013     |
| carb     | 0.4077 | -0.3031  |     -0.7435      |    -1.0244     |     0.0000     |
| cyl      | 0.4030 | -0.4390  |     -1.0894      |    -1.7133     |     0.0000     |
| am       | 0.3878 | -0.2710  |     -0.6988      |    -1.0090     |     0.0000     |
| gear     | 0.1889 | -0.0804  |     -0.4256      |    -0.4925     |     0.0000     |
| mpg      | 0.1675 |  0.0623  |      0.3721      |     0.0000     |     0.4615     |
| drat     | 0.0881 | -0.0134  |     -0.1523      |     0.0000     |     0.0000     |

The MIPs for each predictor can then be visualized using the `plot()`
function.

``` r
plot(results)
```

<img src="man/figures/README-plot-1.png" width="100%" />

## Example 2 - binary response variable

In the example above, the response variable was a continuous variable.
The same workflow can be used for binary variables by specifying
`continuous = FALSE` to the `ssvs()` function.

As an example, let’s create a binary variable:

``` r
library(AER)
#> Warning: package 'AER' was built under R version 4.5.2
data(Affairs)
Affairs$hadaffair[Affairs$affairs > 0] <- 1
Affairs$hadaffair[Affairs$affairs == 0] <- 0
```

Then define the outcome and predictors.

``` r
outcome <- "hadaffair"
predictors <- c("gender", "age", "yearsmarried", "children", "religiousness", "education", "occupation", "rating")
```

And finally run the model:

``` r
set.seed(1000)
results <- ssvs(data = Affairs, x = predictors, y = outcome, continuous = FALSE, progress = FALSE)
```

Now the results can be summarized or visualized in the same manner.

``` r
summary_results <- summary(results, interval = 0.9, ordered = TRUE)
```

| Variable      |  MIP   | Avg Beta | Avg Nonzero Beta | Lower CI (90%) | Upper CI (90%) |
|:--------------|:------:|:--------:|:----------------:|:--------------:|:--------------:|
| rating        | 1.0000 | -0.5521  |     -0.5521      |    -0.7095     |    -0.3866     |
| religiousness | 0.4698 | -0.1588  |     -0.3379      |    -0.4268     |     0.0000     |
| yearsmarried  | 0.1477 |  0.0473  |      0.3206      |     0.0000     |     0.2665     |
| children      | 0.0953 |  0.0270  |      0.2833      |     0.0000     |     0.0000     |
| age           | 0.0147 | -0.0029  |     -0.1990      |     0.0000     |     0.0000     |
| gender        | 0.0115 |  0.0015  |      0.1306      |     0.0000     |     0.0000     |
| occupation    | 0.0095 |  0.0009  |      0.0954      |     0.0000     |     0.0000     |
| education     | 0.0061 |  0.0008  |      0.1347      |     0.0000     |     0.0000     |

``` r
plot(results)
```

<img src="man/figures/README-binary-plot-1.png" width="100%" />

## Example 3 - SSVS with multiple imputation (MI)

First, we will use the `mice()` function from the {mice} package to
perform multiple imputation.

``` r
library(mice)
#> 
#> Attaching package: 'mice'
#> The following object is masked from 'package:stats':
#> 
#>     filter
#> The following objects are masked from 'package:base':
#> 
#>     cbind, rbind

# Load the mtcars dataset
data <- mtcars

# Introduce random missingness in 10% of the data
set.seed(123)  
n <- nrow(data) * ncol(data)
missing_indices <- sample(n, size = 0.1 * n, replace = FALSE)

# Convert missing indices to row-column positions
rows <- (missing_indices - 1) %% nrow(data) + 1
cols <- (missing_indices - 1) %/% nrow(data) + 1

# Assign NA to the identified positions
for (i in seq_along(rows)) {
  data[rows[i], cols[i]] <- NA
}

# Perform multiple imputation using mice
imputed_data <- mice(data, m = 5, maxit = 50, seed = 123)

# Display the results of the imputation
summary(imputed_data)

# Extract and show the first completed dataset
imputed_mtcars <- complete(imputed_data, "long")
head(imputed_mtcars)
```

We will use this multiply imputed data set for SSVS, using the
`ssvs_mi()` function.

``` r
outcome <- 'qsec'
predictors <- c('cyl', 'disp', 'hp', 'drat', 'wt', 'vs', 'am', 'gear', 'carb','mpg')
imputation <- '.imp'
results <- ssvs_mi(data = imputed_mtcars, y = outcome, x = predictors, imp = imputation)
```

The results of SSVS with MI can be summarized with the `summary()` and
`plot()` functions. This will summarize *across imputations* for each
predictor: the average MIP and the mean, minimum, maximum, and average
nonzero beta coefficients.

## Interactive version

You can launch an interactive (shiny) web application that lets you run
SSVS analyses without programming. Simply install this package and run
`SSVS::launch()` in an R console.

helpIcon <- function(...) {
  span(
    class = "help-icon",
    "data-toggle" = "tooltip",
    "data-html" = "true",
    "?",
    title = paste(...)
  )
}

fluidPage(
  title = "SSVS",
  theme = bslib::bs_theme(4),
  lang = "en",

  tags$head(
    tags$link(rel = "preconnect", href = "https://fonts.googleapis.com"),
    tags$link(rel = "preconnect", href = "https://fonts.gstatic.com", crossorigin = NA),
    tags$link(
      rel = "stylesheet",
      href = "https://fonts.googleapis.com/css2?family=Inter:wght@300;700&family=Playfair+Display:wght@700&display=swap"
    ),
    tags$link(rel = "stylesheet", type = "text/css", href = "style.css"),
    tags$script(src = "ssvs.js"),
    shinyjs::useShinyjs()
  ),

  div(
    id = "header",
    h2("SSVS"),
    img(src = "logo.png", id = "logo", alt = "Logo"),
    h3("An interactive web tool for performing stochastic search variable selection")
  ),

  tabsetPanel(
    id = "main_tabs",

    tabPanel(
      "Data",
      value = "data",
      icon = icon("table", "aria-hidden" = "true"),

      br(),
      fluidRow(
        column(
          width = 4,

          fileInput(
            "datafile",
            glue::glue("Choose File (max {FILE_UPLOAD_MB} MB)"),
            width = "75%",
            accept = c(
              "text/csv",
              "text/comma-separated-values,text/plain",
              ".csv",
              ".xls",
              ".xlsx",
              ".sav"
            )
          ),
          br(),

          div(
            class = "message",
            tags$strong("Pre-requisites and constraints"),
            p(
              "The requirements for SSVS are similar to requirements for standard regression analysis.",
              "Currently this application contains functionality for linear and logistic regression.",
              "Categorical predictors must be coded using an appropriate scheme (e.g. dummy coding).",
              "Any cases with missing data in any of the selected predictor variables will be excluded from the analysis (listwise deletion).",
              "There is currently no acceptable procedure for combining results from multiply imputed data sets.",
              "Check the table below to make sure your data imported correctly (e.g. check missing data codes)."
            ),
            p(
              "Because the priors have a fixed scale, predictors on different scales will differentially influence results.",
              "SSVSforPsych automatically standardizes the predictors selected for analysis."
            )
          )
        ),

        column(
          width = 8,
          reactable::reactableOutput("data_desc")
        )
      )
    ),

    tabPanel(
      "Analysis",
      value = "analysis",
      icon = icon("sliders-h", "aria-hidden" = "true"),

      br(),

      fluidRow(
        column(
          width = 6,

          tags$form(
            class = "analysis-form",

            fluidRow(
              column(
                6,

                h5("Main Options"),

                selectInput(
                  "dependent", "Dependent variable",
                  choices = NULL,
                  width = "100%"
                ),

                radioButtons(
                  "logistic",
                  tagList(
                    "The dependent variable is",
                    helpIcon(
                      "<p>If the dependent variable is continuous, the analysis will proceed using a standard Gibbs sampler.</p>",
                      "<p>If the dependent variable is binary, SSVS results will be provided using the logit.spike() function from the BoomSpikeSlab package.</p>"
                    ),
                  ),
                  c("Continuous" = "continuous", "Binary" = "binary"),
                  inline = TRUE,
                  width = "100%"
                ),

                shinyWidgets::pickerInput(
                  "predictors",
                  label = span("Candidate predictors"),
                  choices = NULL,
                  multiple = TRUE,
                  options = list(`actions-box` = TRUE, `none-selected-text` = "None selected"),
                  width = "100%"
                )
              ),

              column(
                6,

                h5("Additional Options"),


                div(
                  id = "additional_options",
                  sliderInput(
                    "prior",
                    label = tagList(
                      "Prior inclusion probablility",
                      helpIcon(
                        "<p>Prior inclusion probablility is applied to all predictors.",
                        "The prior inclusion probability reflects the belief that each predictor should be included in the model.</p>",
                        "<p>A prior probability of 0.5 (the default) reflects the belief that each predictor has an equal probability of being included or excluded.",
                        "Note that a value of 0.5 also implies a prior belief that the true model contains half of the candidate predictors.</p>",
                        "<p>As shown in Bainter et al. (2020), the prior inclusion probability will influence the magnitude of the marginal inclusion probabilities (MIPs),",
                        "but the relative pattern of MIPS is expected to remain fairly consistent.</p>"
                      )
                    ),
                    min = 0.1, max = 0.9, step = 0.1, value = 0.5, ticks = FALSE,
                    width = "100%"
                  ),

                  sliderInput(
                    "burnin",
                    label = tagList(
                      "Burn-in iterations",
                      helpIcon(
                        "<p>Burn-in iterations are the number of discarded warmup iterations used to achieve Markov chain Monte Carlo (MCMC) convergence.</p>",
                        "<p>You may increase the number of burn-in iterations if you are having convergence issues.</p>"
                      )
                    ),
                    min = 1000, max = 10000, step = 1000, value = 1000, ticks = FALSE,
                    width = "100%"
                  ),

                  sliderInput(
                    "nruns",
                    label = tagList(
                      "Total number of iterations",
                      helpIcon(
                        "The total number of iterations (inclusive of burn-in) indicates the number of models sampled. Results are based on the Total - Burn-in iterations."
                      )
                    ),
                    min = 10000, max = 20000, step = 1000, value = 10000, ticks = FALSE,
                    width = "100%"
                  ),

                  conditionalPanel(
                    "input.logistic == 'continuous'",
                    radioButtons(
                      "random_fixed",
                      label = tagList(
                        "Fixed or random start values",
                        helpIcon(
                          "<p>Fixed start values will result in a perfectly reproducible solution produced in each run.</p>",
                          "<p>Random start values allow for slight variations in results due to the randomness inherent in MCMC estimation.</p>",
                          "<p>Checking results with different starting values is a useful method for checking convergence.</p>"
                        )
                      ),
                      c("Fixed" = "fix", "Random" = "random"),
                      inline = TRUE,
                      width = "100%"
                    )
                  ),
                )
              )
            ),

            fluidRow(
              column(
                12,
                uiOutput("missing_cases"),
                actionButton(
                  "run",
                  label = "Run Analysis",
                  icon = icon("play"),
                  class = "btn-success btn-lg",
                  width = "100%"
                ),
                br()
              )
            )
          )
        ),

        column(
          width = 6,

          p(id = "results_memo", "Run analysis to get results"),

          div(
            id = "results_tabs",
            tabsetPanel(
              type = "pills",

              header = div(
                class = "download-buttons",
                downloadButton("download_summary", "Download results"),
                downloadButton("download_plot", "Download plot")
              ),

              tabPanel(
                title = "Table",
                value = "table",
                br(),
                textOutput("result_summary_text"),
                br(),
                reactable::reactableOutput("summary_table")
              ),
              tabPanel(
                title = "Plot",
                value = "plot",
                br(),
                checkboxInput("show_threshold", "Show threshold line at 0.5?", value = TRUE),
                plotOutput("plot"),
                p("To customize the plot, you can run the following code in an R session and modify any of the parameters (make sure to store the dataset in a variable called `data`)."),
                verbatimTextOutput("code")
              )
            )
          )
        )
      )
    ),

    tabPanel(
      "Info",
      value = "info",
      icon = icon("info", "aria-hidden" = "true"),
      br(),
      includeMarkdown("info.md")
    )
  )
)

function(input, output, session) {
  hideTab("main_tabs", "analysis")

  ssvs_result <- reactiveVal()

  rawdata <- reactive({
    req(input$datafile)
    file_type <- tools::file_ext(input$datafile$datapath)

    if (file_type == "csv") {
      read.csv(input$datafile$datapath, header = TRUE)
    } else if (file_type == "xlsx" || file_type == "xls") {
      as.data.frame(readxl::read_excel(input$datafile$datapath, 1, col_names = TRUE))
    } else if (file_type == "sav") {
      foreign::read.spss(input$datafile$datapath, to.data.frame = TRUE, use.value.labels = FALSE)
    } else {
      shinyalert(
        "Unsupported file type",
        type = "error",
        closeOnClickOutside = TRUE
      )
      hideTab("main_tabs", "analysis")
      NULL
    }
  })

  data_desc <- reactive({
    df <- rawdata()
    req(df)

    desc_cols <- c("mean", "sd", "min", "max", "skew")
    desc <- as.data.frame(psych::describe(df))[, desc_cols]
    vars_class <- unname(sapply(df, class))
    vars_missing <- sapply(df, function(x) sum(is.na(x)))

    varlist <- cbind(
      colnames(df),
      desc,
      vars_class,
      vars_missing
    )
    colnames(varlist) <- c(
      "variable",
      desc_cols,
      "type",
      "na_values"
    )
    varlist
  })

  output$data_desc <- reactable::renderReactable({
    reactable::reactable(
      data_desc(),
      rownames = FALSE,
      searchable = TRUE,
      columns = list(
        variable = reactable::colDef(
          name = "Variable"
        ),
        mean = reactable::colDef(
          name = "Mean",
          format = reactable::colFormat(digits = 5)
        ),
        sd = reactable::colDef(
          name = "SD",
          format = reactable::colFormat(digits = 5)
        ),
        min = reactable::colDef(
          name = "Min"
        ),
        max = reactable::colDef(
          name = "Max"
        ),
        skew = reactable::colDef(
          name = "Skew",
          format = reactable::colFormat(digits = 5)
        ),
        type = reactable::colDef(
          name = "Type"
        ),
        na_values = reactable::colDef(
          name = "NA Values"
        )
      )
    )
  })

  observeEvent(rawdata(), {
    showTab("main_tabs", "analysis")
    shinyjs::hide("results_tabs")
    shinyjs::show("results_memo")

    updateSelectInput(session, "dependent", choices = colnames(rawdata()))
    shinyWidgets::updatePickerInput(session, "predictors", choices = colnames(rawdata()))
  })

  data_preclean <- reactive({
    req(rawdata())
    data <- rawdata()[, unique(c(input$dependent, input$predictors))]
  })

  complete_rows <- reactive({
    req(data_preclean())
    complete.cases(data_preclean())
  })

  data_postclean <- reactive({
    req(data_preclean())
    data_preclean()[complete_rows(), ]
  })

  output$missing_cases <- renderUI({
    req(sum(!complete_rows()) > 0)
    div(
      class = "message",
      glue(
        "Note: the data contains {sum(!complete_rows())} row{if (sum(!complete_rows()) > 1) 's' else ''} with missing values in the selected variables. ",
        "If you run the analysis, data in these rows will be ignored."
      )
    )
  })

  observe({
    shinyjs::toggleState("run", condition = (length(input$predictors) >= 2))
  })

  observeEvent(c(input$dependent, input$logistic, input$predictors, input$random_fixed, input$prior, input$nruns, input$burnin), {
    shinyjs::hide("results_tabs")
    shinyjs::show("results_memo")
  })

  observeEvent(input$run, {
    if (length(input$predictors) <= 1) {
      shinyalert(
        "You must choose at least two predictors",
        type = "error",
        closeOnClickOutside = TRUE
      )
      return()
    }

    if (input$random_fixed == "fix") {
      set.seed(820)
    }

    continuous <- (input$logistic == "continuous")

    shinyalert("Running SSVS analysis...",
      type = "warning",
      closeOnEsc = FALSE, showConfirmButton = FALSE
    )

    result <- try(
      SSVS::ssvs(
        data_postclean(),
        x = input$predictors,
        y = input$dependent,
        progress = FALSE,
        continuous = continuous,
        inprob = input$prior,
        runs = input$nruns,
        burn = input$burnin
      ),
      silent = TRUE
    )

    closeAlert()

    if (inherits(result, "try-error")) {
      shinyalert("Error in analysis", attr(result, "condition")$message,
        type = "error",
        closeOnClickOutside = TRUE
      )
      return()
    }

    shinyjs::hide("results_memo")
    shinyjs::show("results_tabs")

    ssvs_result(result)
  })

  ssvs_summary <- reactive({
    req(ssvs_result())
    summary(ssvs_result())
  })
  ssvs_plot <- reactive({
    req(ssvs_result())
    threshold <- if (input$show_threshold) 0.5 else NULL
    plot(ssvs_result(), threshold = threshold)
  })

  output$result_summary_text <- renderText({
    req(ssvs_result())

    glue::glue(
      "{scales::comma(input$nruns)} MCMC iterations run, results for ",
      "{scales::comma(input$nruns - input$burnin)} iterations post-warmup shown below for ",
      "{scales::comma(sum(complete_rows()))} complete cases"
    )
  })

  output$summary_table <- reactable::renderReactable({
    reactable::reactable(
      ssvs_summary(),
      rownames = FALSE,
      searchable = nrow(ssvs_summary()) > 10
    )
  })

  output$download_summary <- downloadHandler(
    "SSVS results.csv",
    function(file) {
      write.csv(ssvs_summary(), file)
    }
  )

  output$plot <- renderPlot({
    ssvs_plot()
  })

  output$download_plot <- downloadHandler(
    "SSVS plot.png",
    function(file) {
      ggplot2::ggsave(file, ssvs_plot())
    }
  )

  output$code <- renderText({

    ssvs_code <- glue(
      "response <- \"{input$dependent}\"\n",
      "predictors <- {paste(utils::capture.output(dput({input$predictors})), collapse = '')}\n",
      "result <- ssvs(",
      "data, ",
      "x = predictors, ",
      "y = response, ",
      "continuous = {as.character(input$logistic == 'continuous')}, ",
      "inprob = {input$prior}, ",
      "runs = {input$nruns}, ",
      "burn = {input$burnin}",
      ")"
    )

    plot_code <- glue(
      "plot(",
      "result, ",
      "threshold = {if (input$show_threshold) 0.5 else 'NULL'}, ",
      "legend = TRUE, ",
      "title = NULL, ",
      "color = TRUE",
      ")"
    )

    glue(
      "library(SSVS)\n",
      "{ssvs_code}\n",
      "{plot_code}"
    )
  })
}

#' Summarize results of an SSVS model
#'
#' Summarize results from SSVS including marginal inclusion probabilities,
#' Bayesian model averaged parameter estimates, and
#' 95% highest posterior density credible intervals. Estimates and
#' credible intervals are based on standardized X variables.
#'
#' @param object An SSVS result object obtained from [`ssvs()`]
#' @param interval The desired probability for the credible interval, specified as a decimal
#' @param threshold Minimum MIP threshold where a predictor will be shown in the output, specified as a decimal
#' @param ordered If `TRUE`, order the results based on MIP (in descending order)
#' @param ... Ignored
#' @examples
#' \donttest{
#' outcome <- "qsec"
#' predictors <- c("cyl", "disp", "hp", "drat", "wt", "vs", "am", "gear", "carb", "mpg")
#' results <- ssvs(data = mtcars, x = predictors, y = outcome, progress = FALSE)
#' summary(results, interval = 0.9, ordered = TRUE)
#' }
#' @return A dataframe with results
#' @export
summary.ssvs <- function(object, interval = 0.89, threshold = 0,
                         ordered = FALSE, ...){
  assert_ssvs(object)
  checkmate::assert_number(interval, lower = 0, upper = 1)
  checkmate::assert_number(threshold, lower = 0, upper = 1)
  checkmate::assert_logical(ordered, len = 1, any.missing = FALSE)

  # Get MIP for each variable
  inc_prob <- as.data.frame(round(apply(object$beta!=0,2,mean),4))

  # Get all post-burnin beta values
  temp.beta.frame <- as.data.frame(object[["beta"]])
  # Get average betas and upper and lower credibility
  average.beta <- NULL
  lower.credibility <- NULL
  upper.credibility <- NULL
  for (m in names(temp.beta.frame)){
    average.beta[m] <- round(mean(temp.beta.frame[,m]),4)
    # 95% credibility interval lower
    lower.credibility[m] <- round(bayestestR::ci(temp.beta.frame[,m], method = "HDI",ci = interval)[[2]],4)
    # 95% credibility interval upper
    upper.credibility[m] <- round(bayestestR::ci(temp.beta.frame[,m], method = "HDI",ci = interval)[[3]],4)
  }

  # Save the average non-zero betas
  temp.beta.frame.nonzero <- temp.beta.frame
  is.na(temp.beta.frame.nonzero) <- temp.beta.frame.nonzero==0

  # Loop
  average.nonzero.beta <- NULL
  for (m in names(temp.beta.frame.nonzero)){
    # Obtain mean
    average.nonzero.beta[m] <- round(mean(temp.beta.frame.nonzero[,m], na.rm = TRUE),4)
  }


  res <- matrix(nrow=ncol(object$beta),ncol=6)

  colnames(res) <- c('Variable', 'MIP', 'Avg Beta','Avg Nonzero Beta',
                     paste0('Lower CI (', interval * 100, '%)'),
                     paste0('Upper CI (', interval * 100, '%)'))

  res[, 1] <- colnames(object$beta)
  res[, 2] <- inc_prob[, 1]
  res[, 3] <- average.beta
  res[, 4] <- average.nonzero.beta
  res[, 5] <- lower.credibility
  res[, 6] <- upper.credibility
  res <- as.data.frame(res)

  res[, 2:6] <- apply(res[, 2:6], 2, function(x) as.numeric(x))


  if (ordered){
    res <- res[order(-res$MIP), ]
  }


  res <- res[res$MIP > threshold, ]
  #set the class of the res object to class "ssvs_summary"
  class(res) <- c("ssvs_summary", class(res))
  res
}

#' Print the summary of an SSVS model
#' @export
#' @keywords internal
print.ssvs_summary <- function(x, ...) {
  print.data.frame(x, right = FALSE, row.names = FALSE)
}

#' Perform SSVS for continuous and binary outcomes
#'
#' For continuous outcomes, a basic Gibbs sampler is used. For binary
#' outcomes, [`BoomSpikeSlab::logit.spike()`] is used.
#'
#' @param data The dataframe used to extract predictors and response values
#' @param y The response variable
#' @param x The set of predictor variables
#' @param continuous If `TRUE`, treat the response variable as continuous. If
#' `FALSE`, treat the response variable as binary.
#' @param prior.probs Numeric vector or scalar specifying the prior probability
#' that each predictor variable is included in the model. If a scalar, the value is
#' replicated for all variables. If a vector, must have legnth equal to length(x).
#' Each value must be between 0 and 1. Setting a prior probability to 1.0 forces
#' that variable to always be included. The default prior inclusion probability is
#' .5 for all predictors. The prior inclusion probabilities will influence the
#' magnitude of the marginal inclusion probabilities (MIPs), but the relative pattern of
#' MIPs is expected to remain fairly consistent.
#' @param inprob **Deprecated**; use `prior.probs` instead.
#' If provided, this overrides `prior.probs` (with a warning).
#' @param force.in Character vector specifying variables that should always be
#' included in the model. This is a convenience parameter that sets prior.probs = 1.0
#' for the specified variables. If both prior.probs and force.in are provided,
#' force.in takes precedence and will override probabilities for those variables.
#' Default is NULL.
#' @param runs Total number of iterations (including burn-in). Results are based on
#' the Total - Burn-in iterations.
#' @param burn Number of burn-in iterations. Burn-in iterations are discarded
#' warmup iterations used to achieve MCMC convergence. You may increase the number
#' of burn-in iterations if you are having convergence issues.
#' @param a1 Prior parameter for Gamma(a,b) distribution on the precision (1/variance)
#' residual variance. Only used when `continuous = TRUE`.
#' @param b1 Prior parameter for Gamma(a,b) distribution on the precision (1/variance)
#' residual variance. Only used when `continuous = TRUE`.
#' @param prec.beta Prior precision (1/variance) for beta coefficients.
#' Only used when `continuous = TRUE`.
#' @param progress If `TRUE`, show progress of the model creation. When `continuous = TRUE`,
#' progress plots will be created for every 1000 iterations. When `continuous = FALSE`,
#' 10 progress messages will be printed.
#' Only used when `continuous = TRUE`.
#' @examples
#' \donttest{
#' # Example 1: Continuous response variable, uniform prior
#' outcome <- "qsec"
#' predictors <- c("cyl", "disp", "hp", "drat", "wt", "vs", "am", "gear", "carb", "mpg")
#' results <- ssvs(data = mtcars, x = predictors, y = outcome,
#' prior.probs = .5, #same for all predictors
#' progress = FALSE)
#'
#'#' # Example 2: Continuous response variable, variable-specific priors
#' outcome <- "mpg"
#' predictors <- c("cyl", "disp", "hp", "wt")
#' prior.probs = c(0.7, 0.5, 0.2, 0.2) # Different prior probability for each
#' results <- ssvs(data = mtcars, x = predictors, y = outcome,
#' progress = FALSE)
#'
#' # Example 3: Binary response variable
#' library(AER)
#' data(Affairs)
#' Affairs$hadaffair[Affairs$affairs > 0] <- 1
#' Affairs$hadaffair[Affairs$affairs == 0] <- 0
#' outcome <- "hadaffair"
#' predictors <- c("gender", "age", "yearsmarried", "children", "religiousness",
#' "education", "occupation", "rating")
#' results <- ssvs(data = Affairs, x = predictors, y = outcome, continuous = FALSE, progress = FALSE)
#'
#' #' # Example 4: Binary response variable with forced inclusion of select predictors
#' library(AER)
#' data(Affairs)
#' Affairs$hadaffair[Affairs$affairs > 0] <- 1
#' Affairs$hadaffair[Affairs$affairs == 0] <- 0
#' outcome <- "hadaffair"
#' predictors <- c("gender", "age", "yearsmarried", "children", "religiousness",
#' "education", "occupation", "rating")
#' results <- ssvs(data = Affairs, x = predictors, y = outcome, force.in = c("children", "rating"),
#' continuous = FALSE, progress = FALSE)
#' }
#' @return An ssvs object that can be used in
#' [`summary()`][`summary.ssvs`] or [`plot()`][`plot.ssvs`].
#' @export
ssvs <- function(data, y, x, continuous = TRUE,
                 prior.probs = 0.5, inprob=NULL,force.in = NULL, runs = 20000, burn = 5000,
                 a1 = 0.01, b1 = 0.01, prec.beta = 0.1, progress = TRUE) {

  checkmate::assert_data_frame(data, min.rows = 1, min.cols = 2)
  checkmate::assert_character(x, any.missing = FALSE, min.len = 1)
  checkmate::assert_character(y, any.missing = FALSE, len = 1)
  checkmate::assert_subset(c(x, y), names(data))
  checkmate::assert_logical(continuous, len = 1, any.missing = FALSE)
  checkmate::assert_integerish(burn, lower = 1, len = 1, any.missing = FALSE)
  checkmate::assert_integerish(runs, lower = burn + 1, len = 1, any.missing = FALSE)
  checkmate::assert_number(a1, lower = 0)
  checkmate::assert_false(a1 == 0)
  checkmate::assert_number(b1, lower = 0)
  checkmate::assert_false(b1 == 0)
  checkmate::assert_number(prec.beta, lower = 0)
  checkmate::assert_false(prec.beta == 0)
  checkmate::assert_logical(progress, len = 1, any.missing = FALSE)

  # NEW: Compute inclusion probabilities with validation
    # Deprecation handling for 'inprob'
    if (!is.null(inprob)) {
      warning("The 'inprob' argument is **deprecated**. Please use 'prior.probs' instead.",
              call. = FALSE)
      prior.probs <- inprob  # use the old value for backwards compatibility
      }

  inclusion_probs <- compute_inclusion_probs(
    x = x,
    prior.probs = prior.probs,
    force.in = force.in,
    continuous = continuous
    )

  if (continuous) {
    ssvs <- ssvs_continuous(
      data = data, y = y, x = x,
      inclusion_probs = inclusion_probs,  # CHANGED: pass computed probs
      runs = runs, burn = burn,
      a1 = a1, b1 = b1, prec.beta = prec.beta, progress = progress
    )
  } else {
    ssvs <- ssvs_binary(
      data = data, y = y, x = x,
      inclusion_probs = inclusion_probs,  # CHANGED: pass computed probs
      runs = runs, burn = burn, progress = progress
    )
  }
  #class(ssvs)<- sets the class of the ssvs output object to class "ssvs"
  class(ssvs) <- c("ssvs", class(ssvs))
  #sets the "response" attribute of ssvs object to y. Setting this attribute here
  #to be used for setting the title in the plot.ssvs
  attr(ssvs, "response") <- y
  ssvs
}

ssvs_continuous <- function(data, y, x, inclusion_probs,
                            runs, burn, a1, b1, prec.beta, progress) {
  y <- data[, y]
  x <- data[, x]

  # error message for missing values
  if (sum(is.na(x)) + sum(is.na(y)) > 0) {
    stop("Missing values in selection")
  }

  # Added scaling inside function for X only
  x <- scale(x)

  p <- ncol(x)
  xp <- matrix(0, 25, p)
  xp[, 1] <- seq(-3, 3, length = 25)
  n <- length(y)
  np <- nrow(xp)

  # initial values:

  int <- mean(y)
  beta <- rep(0, p)
  alpha <- rep(0, p)
  delta <- rep(0, p)
  taue <- 1 / stats::var(y)

  # keep track of stuff:

  keep.beta <- matrix(0, runs, p)
  colnames(keep.beta) <- colnames(x)
  keep.int <- keep.taue <- rep(0, runs)
  keep.yp <- matrix(0, runs, np)

  # LET'S ROLL:
  for (i in 1:runs) {
    taue <- stats::rgamma(1, n / 2 + a1, sum((y - int - x %*% beta)^2) / 2 + b1)
    int <- stats::rnorm(1, mean(y - x %*% beta), 1 / sqrt(n * taue))

    # update alpha
    z <- x %*% diag(delta)
    V <- solve(taue * t(z) %*% z + prec.beta * diag(p))
    M <- taue * t(z) %*% (y - int)
    alpha <- V %*% M + t(chol(V)) %*% stats::rnorm(p)
    beta <- alpha * delta

    # update inclusion indicators:
    r <- y - int - x %*% beta
    for (j in 1:p) {
      r <- r + x[, j] * beta[j]
      #CHANGED: use variable specific prior probability
      log.p.in <- log(inclusion_probs[j]) - 0.5 * taue * sum((r - x[, j] * alpha[j])^2)
      log.p.out <- log(1 - inclusion_probs[j]) - 0.5 * taue * sum(r^2)
      diff <- log.p.in - log.p.out
      diff <- ifelse(diff > 10, 10, diff)
      p.in <- stats::plogis(diff)
      delta[j] <- stats::rbinom(1, 1, p.in)
      beta[j] <- delta[j] * alpha[j]
      r <- r - x[, j] * beta[j]
    }

    # Make predictions:
    yp <- stats::rnorm(np, int + xp %*% beta, 1 / sqrt(taue))

    # Store the output:
    keep.beta[i, ] <- beta
    keep.int[i] <- int
    keep.taue[i] <- taue
    keep.yp[i, ] <- yp

    if ((i %% 1000 == 0) & (progress == TRUE)) {
      plot(beta, main = paste("Iteration", i))
      graphics::abline(0, 0)
    }
  }

  result <- list(
    beta = keep.beta[burn:runs, ],
    int = keep.int[burn:runs],
    taue = keep.taue[burn:runs],
    pred = keep.yp[burn:runs, ]
  )

  result
}

ssvs_binary <- function(data, y, x, inclusion_probs, runs, burn, progress) {
  # Automatically convert any two-level factors to binary variables
  for (i in 1:ncol(data[,x])){
    if (length(levels(data[,i]))==2){
      data[,i] <- as.numeric(data[,i]) - 1
      message("Two level factor converted to binary")
    }
  }

  x <- data[,x]
  y <- data[,y]

  # Scale inputs
  x <- scale(as.matrix(x))
  y <- (as.matrix(y))

  # Make a column of 1s for the design matrix
  intercept <- rep(1, nrow(x))

  # Create design matrix that includes the column of 1s, and the predictors
  designMatrix <- as.matrix(cbind(intercept, x))

  # Save the prior value to use
  myPrior <- BoomSpikeSlab::LogitZellnerPrior(predictors = designMatrix,
                                              successes = y,
                                              trials = NULL,
                                              prior.inclusion.probabilities = inclusion_probs,
                                              expected.model.size = sum(inclusion_probs),)




  ## logit.spike()
  if (progress) {
    ping <- runs / 10
  } else {
    ping <- 0
  }
  bssResults <- BoomSpikeSlab::logit.spike(formula = as.matrix(y) ~ as.matrix(x),
                                           niter = runs,
                                           prior = myPrior,
                                           ping = ping)
  bssResults[["beta"]] <- as.data.frame(bssResults[["beta"]][-c(1:burn),-1])

  colnames(bssResults[["beta"]]) <- colnames(x)

  bssResults
}

test_that("ssvs argument error checking works", {
  predictors <- c("cyl", "disp", "hp", "drat", "wt", "vs", "am", "gear", "carb", "mpg")
  outcome <- "qsec"

  expect_error(ssvs())
  expect_error(ssvs("nodata", x = predictors, y = outcome))
  expect_error(ssvs(mtcars, x = "novar", y = outcome))
  expect_error(ssvs(mtcars, x = predictors, y = "novar"))
  expect_error(ssvs(mtcars, x = predictors, y = outcome, prior.probs = 2))
  expect_error(ssvs(mtcars, x = predictors, y = outcome, burn = 0))
  expect_error(ssvs(mtcars, x = predictors, y = outcome, burn = 1000, runs = 1000))
  expect_error(ssvs(mtcars, x = predictors, y = outcome, burn = 0))
  expect_error(ssvs(mtcars, x = predictors, y = outcome, burn = 1.5))
  expect_error(ssvs(mtcars, x = predictors, y = outcome, runs = 0))
  expect_error(ssvs(mtcars, x = predictors, y = outcome, a1 = 0))
  expect_error(ssvs(mtcars, x = predictors, y = outcome, b1 = 0))
  expect_error(ssvs(mtcars, x = predictors, y = outcome, prec.beta = 0))
  expect_error(ssvs(mtcars, x = predictors, y = outcome, progress = "nobool"))
})

test_that("ssvs works", {
  predictors <- c("cyl", "disp", "hp", "drat", "wt", "vs", "am", "gear", "carb", "mpg")
  outcome <- "qsec"

  set.seed(1000)
  results_simple <- ssvs(data = mtcars, y = outcome, x = predictors, progress = FALSE)

  # Check structure
  expect_s3_class(results_simple, "ssvs")
  expect_equal(dim(results_simple$beta), c(15001, 10))
  expect_equal(dim(results_simple$pred), c(15001, 25))
  expect_length(results_simple$int, 15001)
  expect_length(results_simple$taue, 15001)
  expect_equal(colnames(results_simple$beta), predictors)

  # Check posterior means are in a reasonable range
  beta_means <- colMeans(results_simple$beta)
  expect_true(all(beta_means > -5 & beta_means < 5))

  # Check precision is positive
  expect_true(all(results_simple$taue > 0))
})

test_data <- data.frame(  Y = rnorm(10),  X1 = rnorm(10),  X2 = rnorm(10))

test_that("inprob is deprecated but still works", {
  expect_warning({
    set.seed(123)
    result1 <- ssvs(test_data, y = "Y", x = c("X1","X2"), inprob = 0.4)},
    regexp = "deprecated")

  set.seed(123)
  result2 <- ssvs(test_data, y = "Y", x = c("X1","X2"), prior.probs = 0.4)
  expect_identical(result1, result2, tolerance = 1e-8)
  })

expect_summary_eq <- function(x, y) {
  class(x) <- setdiff(class(x), "ssvs_summary")
  class(y) <- setdiff(class(y), "ssvs_summary")
  expect_equal(x, y)
}

test_that("summary works", {
  predictors <- c("cyl", "disp", "hp", "drat", "wt", "vs", "am", "gear", "carb", "mpg")
  outcome <- "qsec"
  set.seed(1000)
  results_simple <- ssvs(data = mtcars, x = predictors, y = outcome, progress = FALSE)

  s <- summary(results_simple, interval = 0.95)

  # Check class
  expect_s3_class(s, "ssvs_summary")

  # Check structure
  expect_equal(nrow(s), length(predictors))
  expect_true(all(s$MIP >= 0 & s$MIP <= 1))
  expect_true(all(s$`Lower CI (95%)` <= s$`Upper CI (95%)`))

  # Check known high/low inclusion predictors
  expect_true(s$MIP[s$Variable == "wt"] > 0.5)
  expect_true(s$MIP[s$Variable == "drat"] < 0.2)

  # Check ordering
  s_ordered <- summary(results_simple, interval = 0.95, ordered = TRUE)
  expect_equal(s_ordered$MIP, sort(s$MIP, decreasing = TRUE))

  # Check threshold
  expect_equal(nrow(summary(results_simple, interval = 0.95, threshold = 0.5)), 3)
})

is_ssvs <- function(x) {
  inherits(x, "ssvs")
}

assert_ssvs <- function(x) {
  if (!is_ssvs(x)) {
    stop("You must provide an SSVS object", call. = FALSE)
  }
  invisible(TRUE)
}

assert_ssvs_mi <- function(object) {
  if (!inherits(object, "ssvs_mi")) {
    stop("The input must be an object of class 'ssvs_mi'.", call. = FALSE)
  }
}

compute_inclusion_probs <- function(x,
                                    prior.probs = .5,
                                    force.in = NULL,
                                    continuous = TRUE) {

  n_vars <- length(x)

  ## Step 1: Create base prior probabilities

    # Validation
    if (length(prior.probs) == 1) {
      # Scalar - replicate for all variables
      probs <- rep(prior.probs, n_vars)
    } else if (length(prior.probs) == n_vars) {
      # Vector - use as provided
      probs <- prior.probs
    } else {
      stop("prior.probs must have length 1 or length(x) = ", n_vars,
      "\nYou provided length ", length(prior.probs),
      call. = FALSE
      )
    }

    if (any(probs < 0) || any(probs > 1)) {
      invalid_idx <- which(probs < 0 | probs > 1)
      stop(
        "All 'prior.probs' values must be between 0 and 1.\n",
        "Invalid values at positions: ", paste(invalid_idx, collapse = ", "),
        call. = FALSE
       )
      }


  ## Step 2: Override probabilities for forced variables
  if (!is.null(force.in)) {
    force_idx <- match(force.in, x)
    if (any(is.na(force_idx))) {
      missing <- force.in[is.na(match(force.in, x))]
      stop(
        "Variables specified in 'force.in' not found in 'x': ",
        paste(missing, collapse = ", "),
        call. = FALSE
      )
    }
    # Warn if overriding user-specified probabilities
    if (length(prior.probs) > 1 && any(prior.probs[force_idx] < 1.0)) {
      warning(
        "Overriding user-specified 'prior.probs' for forced variables to 1.0.\n",
        "Forced variables: ", paste(x[force_idx], collapse = ", "),
        call. = FALSE
      )
    }
    # Set forced variables to probability 1.0
    probs[force_idx] <- 1.0
  }

  if (continuous) {
    #Name and return
    names(probs) <- x
    return(probs)  # No intercept in continuous version
    } else {
      probs<-c(1, probs)
      names(probs) <-c("(Intercept)",x)
        return(probs)  # Intercept always included in binary version  }
      }

    return(probs)
    }

test_that("is_ssvs", {
  expect_error(is_ssvs())
  expect_false(is_ssvs(NULL))
  expect_false(is_ssvs("string"))
  expect_true(is_ssvs(ssvs(mtcars, x = c("mpg", "cyl", "disp"), y = "qsec", progress = FALSE)))
})


test_that("assert_ssvs", {
  expect_error(assert_ssvs())
  expect_error(assert_ssvs(NULL))
  expect_error(assert_ssvs("string"))
  expect_true(assert_ssvs(ssvs(mtcars, x = c("mpg", "cyl", "disp"), y = "qsec", progress = FALSE)))
})

#' Run an interactive analysis tool (Shiny app) that lets you perform SSVS in a browser
#' @export
launch <- function() {
  shiny::runApp(
    system.file("shiny", package = "SSVS"),
    display.mode = "normal",
    launch.browser = TRUE
  )
}

#' Plot SSVS-MI Estimates and Marginal Inclusion Probabilities (MIP)
#'
#' This function creates a plot of SSVS-MI estimates with minimum and maximum and a plot for marginal
#' inclusion probabilities (MIP) optional thresholds for highlighting significant predictors..
#'
#' @param x An ssvs result object obtained from [`ssvs_mi()`]
#' @param type Defaults to "both", can change to "estimate" or "MIP".
#' @param est_title A character string specifying the plot title. Defaults to `"SSVS-MI estimates"`.
#' @param threshold A numeric value (between 0 and 1) specifying the MIP threshold to highlight significant predictors.
#'   Defaults to 0.5.
#' @param legend Logical indicating whether to include a legend for the threshold. Defaults to `TRUE`.
#' @param mip_title A character string specifying the plot title. Defaults to `"Multiple Inclusion Probability for SSVS-MI"`.
#' @param color Logical indicating whether to use color to highlight thresholds. Defaults to `TRUE`.
#' @param ... Ignored
#' @return Two `ggplot2` objects representing the plot of SSVS estimates and the plot of MIP with thresholds.
#' @examples
#' \donttest{
#' data(imputed_mtcars)
#' outcome <- 'qsec'
#' predictors <- c('cyl', 'disp', 'hp', 'drat', 'wt', 'vs', 'am', 'gear', 'carb','mpg')
#' imputation <- '.imp'
#' results <- ssvs_mi(data = imputed_mtcars, y = outcome, x = predictors, imp = imputation)
#' plot(results)
#' }
#' @export
plot.ssvs_mi <- function(x, type = "both", threshold = 0.5, legend = TRUE,
                         est_title = NULL, mip_title = NULL, color = TRUE, ...) {
  assert_ssvs_mi(x)
  checkmate::assert_number(threshold, lower = 0, upper = 1, null.ok = TRUE)
  checkmate::assert_logical(legend, len = 1, any.missing = FALSE)
  checkmate::assert_string(est_title, null.ok = TRUE)
  checkmate::assert_string(mip_title, null.ok = TRUE)

  vars = c("Avg Beta", "MIP")
  vars_out = c("Variables", "avg.beta", "min.beta", "max.beta",
               "avg.mip", "min.mip", "max.mip")
  vars_names = c("Variables", "Avg Beta", "Min Beta", "Max Beta",
                 "Avg MIP", "Min MIP", "Max MIP")
  temp <- x %>%
    as.data.frame() %>%
    dplyr::rowwise() %>%
    dplyr::mutate(
      avg.beta = mean(dplyr::c_across(dplyr::contains(vars[1])), na.rm = TRUE),
      min.beta = min(dplyr::c_across(dplyr::contains(vars[1])), na.rm = TRUE),
      max.beta = max(dplyr::c_across(dplyr::contains(vars[1])), na.rm = TRUE)
    ) %>%
    dplyr::mutate(
      avg.mip = mean(dplyr::c_across(dplyr::contains(vars[2])), na.rm = TRUE),
      min.mip = min(dplyr::c_across(dplyr::contains(vars[2])), na.rm = TRUE),
      max.mip = max(dplyr::c_across(dplyr::contains(vars[2])), na.rm = TRUE)
    ) %>%
    dplyr::ungroup() %>%
    dplyr::select(vars_out[1], vars_out[2], vars_out[3], vars_out[4],
                  vars_out[5], vars_out[6], vars_out[7])

  data <- temp
  colnames(data) <- c("Variables", "Avg Beta", "Min Beta", "Max Beta",
                      "Avg MIP", "Min MIP", "Max MIP")


  if (is.null(est_title)) {
    est_title <- "SSVS-MI estimates"
  }

  p1 <- ggplot2::ggplot(data=data, ggplot2::aes(x = .data[["Variables"]],
                                            y = .data[["Avg Beta"]])) +
      ggplot2::geom_errorbar(
        ggplot2::aes(ymin = .data[["Min Beta"]], ymax = .data[["Max Beta"]]),
        position = "dodge", width = 0.2
      ) +
      ggplot2::geom_point() +
      ggplot2::labs(
        title = est_title,
        x = "Variables",
        y = "Mean Coefficients"
      ) +
      ggplot2::theme_classic()

  plotDF <- temp
  plotDF <- plotDF[order(-plotDF$avg.mip),]

  if (is.null(threshold)) {
    plotDF$threshold <- as.factor(0)
  } else {
    plotDF$threshold <- ifelse(plotDF$avg.mip > threshold, 1, 0)
    plotDF$threshold <- factor(plotDF$threshold, levels = c(0, 1))
    levels(plotDF$threshold) <- c(paste0('< ', threshold), paste0('> ', threshold))
  }

  if (is.null(mip_title)) {
    mip_title <- "Marginal Inclusion Probability for SSVS-MI"
  }

  if (color) {
    cols <- c("#FF4D1C", "#225C3E")
  } else {
    cols <- c("black", "black")
  }

  p2 <- ggplot2::ggplot(data = plotDF) +
    ggplot2::geom_point(ggplot2::aes(x = stats::reorder(.data[["Variables"]], -.data[["avg.mip"]]),
                                     y = .data[["avg.mip"]],
                                     shape = .data[["threshold"]],
                                     color = .data[["threshold"]]),
                        linewidth = 2) +
    ggplot2::geom_errorbar(ggplot2::aes(x = .data[["Variables"]],
                                        y = .data[["avg.mip"]],
                                        ymin = .data[["min.mip"]],
                                        ymax = .data[["max.mip"]]),
                           width = .10,
                           position = "dodge") +
    ggplot2::labs(y = "Marginal Inclusion Probability",
                  x = "Predictor variables",
                  title = mip_title) +
    ggplot2::scale_y_continuous(limits = c(0,1.1), breaks = c(0, .25, .5, .75, 1)) +
    ggplot2::scale_color_manual(values = cols) +
    ggplot2::theme_classic() +
    ggplot2::geom_vline(xintercept = nrow(plotDF)+.5, linetype = 1, linewidth = .5, alpha = .2) +
    ggplot2::theme(axis.text.x = ggplot2::element_text(angle = 90, hjust = 1),
                   panel.spacing = ggplot2::unit(0, "lines"),
                   strip.background = ggplot2::element_blank(),
                   strip.placement = "outside")

  if (!is.null(threshold)) {
    p2 <- p2 +
      ggplot2::labs(shape = "MIP threshold", color = "MIP threshold") +
      ggplot2::geom_hline(yintercept = threshold, linetype = 2)
    if (legend) {
      p2 <- p2 + ggplot2::guides(shape = "legend", color = "legend")
    } else {
      p2 <- p2 + ggplot2::guides(shape = "none", color = "none")  # Correctly disable the legends using "none"
    }
  }

  if (type=="both") {
    gridExtra::grid.arrange(p1,p2)
  } else if (type=="estimate") {
    p1
  } else if (type=="MIP") {
    p2
  }


}

#' Imputed mtcars Dataset
#'
#' This dataset is a version of the `mtcars` dataset where random missing values
#' were introduced, and multiple imputation was performed using the `mice` package.
#'
#' @format A data frame with 160 rows and 13 variables
#' @details
#' Random missingness was introduced into 10% of the values in the original `mtcars` dataset.
#' Multiple imputation was then performed using the `mice` package with the following parameters:
#' \itemize{
#'   \item 5 multiple imputations (`m = 5`).
#'   \item 50 iterations per imputation (`maxit = 50`).
#'   \item Seed set to 123 for reproducibility.
#' }
#' The dataset included here is the first completed dataset resulting from the multiple imputation process.
#'
#' @examples
#' \donttest{
#' data(imputed_mtcars)
#' head(imputed_mtcars)
#' }
#' @source Original dataset from `datasets::mtcars`, with missing values introduced and imputed.
"imputed_mtcars"

#' Perform SSVS on Multiply Imputed Datasets
#'
#' This function performs Stochastic Search Variable Selection (SSVS) analysis on multiply imputed datasets
#' for a given set of predictors and a response variable. It supports continuous response variables and calculates
#' aggregated results across multiple imputations.
#'
#' @param data A dataframe containing the variables of interest, including an `.imp` column for imputation identifiers.
#' @param y The response variable (character string).
#' @param x A vector of predictor variable names.
#' @param imp The imputation variable.
#' @param imp_num The number of imputations to process (default is 5).
#' @param interval Confidence interval level for summary results (default is 0.9).
#' @param continuous If `TRUE`, treat the response variable as continuous. If
#' `FALSE`, treat the response variable as binary.
#' @param progress Logical indicating whether to display progress (default is FALSE).
#'
#' @examples
#' \donttest{
#' # example 1: continuous response variable
#' data(imputed_mtcars)
#' outcome <- 'qsec'
#' predictors <- c('cyl', 'disp', 'hp', 'drat', 'wt', 'vs', 'am', 'gear', 'carb','mpg')
#' imputation <- '.imp'
#' results <- ssvs_mi(data = imputed_mtcars, y = outcome, x = predictors, imp = imputation)
#'
#' # example 2: binary response variable
#' data(imputed_affairs)
#' outcome <- "hadaffair"
#' predictors <- c("gender", "age", "yearsmarried", "children", "religiousness",
#' "education", "occupation", "rating")
#' imputation <- '.imp'
#' results <- ssvs_mi(data = imputed_affairs, x = predictors, y = outcome,
#' continuous = FALSE, imp = imputation)
#' }
#' @return An ssvs_mi object containing aggregated results across imputations that can be
#' used in [`summary()`][`summary.ssvs_mi()`].
#' @export
ssvs_mi <- function(data, y, x, imp, imp_num = 5,
                    interval = 0.9, continuous = TRUE, progress = FALSE) {
  checkmate::assert_data_frame(data, min.rows = 1)
  checkmate::assert_character(y, len = 1)
  checkmate::assert_character(x, min.len = 1)
  checkmate::assert_character(imp, min.len = 1)
  checkmate::assert_logical(continuous, len = 1)
  checkmate::assert_logical(progress, len = 1)

  final_results <- data.frame(Variables = x)

  for (i in 1:imp_num) {
    ind <- data[, imp]
    temp <- data[which(ind==i), ]
    results <- SSVS::ssvs(data = temp, x = x, y = y, continuous = continuous, progress = progress)
    summary_results <- summary(results, interval = interval, ordered = FALSE)
    final_results <- merge(final_results, summary_results[, c('MIP', 'Avg Beta', 'Avg Nonzero Beta')], by = 0, all = TRUE, sort = FALSE) [-1]
    names(final_results)[names(final_results) == "MIP"] <- paste(i, "MIP")
    names(final_results)[names(final_results) == "Avg Beta"] <- paste(i, "Avg Beta")
    names(final_results)[names(final_results) == 'Avg Nonzero Beta'] <- paste(i,'Avg Nonzero Beta')
  }

  class(final_results) <- c("ssvs_mi", class(final_results))
  attr(final_results, "response") <- y

  final_results
}

#' Imputed affairs Dataset
#'
#' This dataset is a version of the `Affairs` dataset where random missing values
#' were introduced, and multiple imputation was performed using the `mice` package.
#'
#' @format A data frame with 3005 rows and 12 variables
#' @details
#' Random missingness was introduced into 10% of the values in the original `Affairs` dataset.
#' Multiple imputation was then performed using the `mice` package with the following parameters:
#' \itemize{
#'   \item 5 multiple imputations (`m = 5`).
#'   \item 50 iterations per imputation (`maxit = 50`).
#'   \item Seed set to 123 for reproducibility.
#' }
#' The dataset included here is the first completed dataset resulting from the multiple imputation process.
#'
#' @examples
#' \donttest{
#' data(imputed_affairs)
#' head(imputed_affairs)
#' }
#' @source Original dataset from `datasets::Affairs`, with missing values introduced and imputed.
"imputed_affairs"

#' Calculate Summary Statistics for SSVS-MI Results
#'
#' Computes summary statistics (average, minimum, and maximum) for beta coefficients, MIP and
#' average nonzero beta coefficients from an SSVS result object.
#'
#' @param object An ssvs_mi result object obtained from [`ssvs_mi()`]
#' @param ... Ignored
#' @examples
#' \donttest{
#' data(imputed_mtcars)
#' outcome <- 'qsec'
#' predictors <- c('cyl', 'disp', 'hp', 'drat', 'wt', 'vs', 'am', 'gear', 'carb','mpg')
#' imputation <- '.imp'
#' results <- ssvs_mi(data = imputed_mtcars, y = outcome, x = predictors, imp = imputation)
#' summary_MI<-summary(results)
#' print(summary_MI)
#' }
#' @return A data frame with results
#' @export
summary.ssvs_mi <- function(object, ...) {
  assert_ssvs_mi(object)

  vars = c("Avg Beta", "MIP", "Avg Nonzero Beta")
  vars_out = c("Variables", "avg.beta", "min.beta", "max.beta",
               "avg.mip", "min.mip", "max.mip",
               "avg.nonzero", "min.nonzero", "max.nonzero")
  res <- object %>%
    as.data.frame() %>%
    dplyr::rowwise() %>%
    dplyr::mutate(
      avg.beta = mean(dplyr::c_across(dplyr::contains(vars[1])), na.rm = TRUE),
      min.beta = min(dplyr::c_across(dplyr::contains(vars[1])), na.rm = TRUE),
      max.beta = max(dplyr::c_across(dplyr::contains(vars[1])), na.rm = TRUE)
    ) %>%
    dplyr::mutate(
      avg.mip = mean(dplyr::c_across(dplyr::contains(vars[2])), na.rm = TRUE),
      min.mip = min(dplyr::c_across(dplyr::contains(vars[2])), na.rm = TRUE),
      max.mip = max(dplyr::c_across(dplyr::contains(vars[2])), na.rm = TRUE)
    ) %>%
    dplyr::mutate(
      avg.nonzero = mean(dplyr::c_across(dplyr::contains(vars[3])), na.rm = TRUE),
      min.nonzero = min(dplyr::c_across(dplyr::contains(vars[3])), na.rm = TRUE),
      max.nonzero = max(dplyr::c_across(dplyr::contains(vars[3])), na.rm = TRUE)
    ) %>%
    dplyr::ungroup() %>%
    dplyr::select(vars_out[1], vars_out[2], vars_out[3], vars_out[4],
                  vars_out[5], vars_out[6], vars_out[7],
                  vars_out[8], vars_out[9], vars_out[10])

  colnames(res) <- c("Variable", "Avg Beta", "Min Beta", "Max Beta",
                     "Avg MIP", "Min MIP", "Max MIP",
                     "Avg Nonzero Beta", "Min Nonzero Beta", "Max Nonzero Beta")

  class(res) <- c("ssvs_mi_summary", class(res))
  res
}


#' Print the summary of ssvs_mi
#' @export
#' @keywords internal
print.ssvs_mi_summary <- function(x, ...) {
  print.data.frame(x, right = FALSE, row.names = FALSE)
}

#' Plot results of an SSVS model
#'
#' @param x An ssvs result object obtained from [`ssvs()`]
#' @param threshold An MIP threshold to show on the plot, must be between 0-1.
#' If `NULL`, no threshold is used.
#' @param legend If `TRUE`, show a legend for the shapes based on the threshold.
#' Ignored if `threshold = NULL`.
#' @param title The title of the plot. Set to `NULL` to use a default title.
#' @param color If `TRUE`, the data points will be colored based on the threshold.
#' @param ... Ignored
#' @examples
#' \donttest{
#' outcome <- "qsec"
#' predictors <- c("cyl", "disp", "hp", "drat", "wt", "vs", "am", "gear", "carb", "mpg")
#' results <- ssvs(x = predictors, y = outcome, data = mtcars, progress = FALSE)
#' plot(results)
#' }
#' @return Creates a plot of the inclusion probabilities by variable
#' @export
#' @importFrom rlang .data
plot.ssvs <- function(x, threshold = 0.5, legend = TRUE, title = NULL, color = TRUE,
                      ...) {
  # Basic checks and setup
  assert_ssvs(x)
  checkmate::assert_number(threshold, lower = 0, upper = 1, null.ok = TRUE)
  checkmate::assert_logical(legend, len = 1, any.missing = FALSE)
  checkmate::assert_string(title, null.ok = TRUE)

  # Data preparation
  plotDF <- as.data.frame(apply(x$beta != 0, 2, mean))
  plotDF$var <- rownames(plotDF)
  names(plotDF) <- c("Inclusion_probability", "Variable_name")
  plotDF <- plotDF[order(-plotDF$Inclusion_probability),]

  if (is.null(threshold)) {
    plotDF$threshold <- as.factor(0)
  } else {
    plotDF$threshold <- ifelse(plotDF$Inclusion_probability > threshold, 1, 0)
    plotDF$threshold <- factor(plotDF$threshold, levels = c(0, 1))
    levels(plotDF$threshold) <- c(paste0('< ', threshold), paste0('> ', threshold))
  }

  if (is.null(title)) {
    title <- paste("Inclusion Probability for", attr(x, "response"))
  }

  if (color) {
    cols <- c("#FF4D1C", "#225C3E")
  } else {
    cols <- c("black", "black")
  }

  plt <- ggplot2::ggplot(data = plotDF) +
    ggplot2::geom_point(ggplot2::aes(x = stats::reorder(.data[["Variable_name"]], -.data[["Inclusion_probability"]]),
                                     y = .data[["Inclusion_probability"]],
                                     shape = .data[["threshold"]],
                                     color = .data[["threshold"]]),
                        size = 2) +
    ggplot2::labs(y = "Inclusion Probability",
                  x = "Predictor variables",
                  title = title) +
    ggplot2::scale_y_continuous(limits = c(0,1.1), breaks = c(0, .25, .5, .75, 1)) +
    ggplot2::scale_color_manual(values = cols) +
    ggplot2::theme_classic() +
    ggplot2::geom_vline(xintercept = nrow(plotDF)+.5, linetype = 1, size = .5, alpha = .2) +
    ggplot2::theme(axis.text.x = ggplot2::element_text(angle = 90, hjust = 1),
                   panel.spacing = ggplot2::unit(0, "lines"),
                   strip.background = ggplot2::element_blank(),
                   strip.placement = "outside")

  if (!is.null(threshold)) {
    plt <- plt +
      ggplot2::labs(shape = "MIP threshold", color = "MIP threshold") +
      ggplot2::geom_hline(yintercept = threshold, linetype = 2)
    if (legend) {
      plt <- plt + ggplot2::guides(shape = "legend", color = "legend")
    } else {
      plt <- plt + ggplot2::guides(shape = "none", color = "none")  # Correctly disable the legends using "none"
    }
  }

  plt
}

#### The purpose of SSVS, and how to use this tool:

The overall goal of SSVS is to provide information about the relative importance of predictors, accounting for uncertainty in which other predictors are included in the model. SSVS samples thousands of regression models in order to characterize the model uncertainty regarding both the predictor set and the regression parameters. The models are selected using a sampling process that is designed to select among “good” models, that is, models with high probability.

After sampling, rather than selecting the best model according to a specified criterion (e.g., the best Akaike’s or Bayesian information criterion or the highest model R2), researchers can examine the proportion of times each predictor was selected, which provides information about which predictors reliably predict the outcome, accounting for uncertainty in the other predictors in the model. Please see Bainter, McCauley, Wager, and Losin (2020) for more details.

The key quantity obtained by SSVS is the marginal inclusion probability (MIP), which is the proportion of times each predictor was included in the sampled models. Predictors with higher MIPs are consistent predictors of the dependent variable, accounting for uncertainty in the other variables included in the models.

<br/>

#### How to cite:

This web tool may be cited in APA style as:

Bainter, S. A., McCauley, T. G., Wager, T., & Losin, E. A. R. (2020). Improving practices for selecting a subset of important predictors in psychology: An application to predicting pain. Advances in Methods in Psychological Science, 3(1), 66-80. https://doi.org/10.1177/2515245919885617

<br/>

#### Contact us

If you encounter any problems, please contact us at ssvsforpsych@gmail.com

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/SSVS_MI.R
\name{ssvs_mi}
\alias{ssvs_mi}
\title{Perform SSVS on Multiply Imputed Datasets}
\usage{
ssvs_mi(
  data,
  y,
  x,
  imp,
  imp_num = 5,
  interval = 0.9,
  continuous = TRUE,
  progress = FALSE
)
}
\arguments{
\item{data}{A dataframe containing the variables of interest, including an \code{.imp} column for imputation identifiers.}

\item{y}{The response variable (character string).}

\item{x}{A vector of predictor variable names.}

\item{imp}{The imputation variable.}

\item{imp_num}{The number of imputations to process (default is 5).}

\item{interval}{Confidence interval level for summary results (default is 0.9).}

\item{continuous}{If \code{TRUE}, treat the response variable as continuous. If
\code{FALSE}, treat the response variable as binary.}

\item{progress}{Logical indicating whether to display progress (default is FALSE).}
}
\value{
An ssvs_mi object containing aggregated results across imputations that can be
used in \code{\link[=summary.ssvs_mi]{summary()}}.
}
\description{
This function performs Stochastic Search Variable Selection (SSVS) analysis on multiply imputed datasets
for a given set of predictors and a response variable. It supports continuous response variables and calculates
aggregated results across multiple imputations.
}
\examples{
\donttest{
# example 1: continuous response variable
data(imputed_mtcars)
outcome <- 'qsec'
predictors <- c('cyl', 'disp', 'hp', 'drat', 'wt', 'vs', 'am', 'gear', 'carb','mpg')
imputation <- '.imp'
results <- ssvs_mi(data = imputed_mtcars, y = outcome, x = predictors, imp = imputation)

# example 2: binary response variable
data(imputed_affairs)
outcome <- "hadaffair"
predictors <- c("gender", "age", "yearsmarried", "children", "religiousness",
"education", "occupation", "rating")
imputation <- '.imp'
results <- ssvs_mi(data = imputed_affairs, x = predictors, y = outcome,
continuous = FALSE, imp = imputation)
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_MI.R
\name{summary.ssvs_mi}
\alias{summary.ssvs_mi}
\title{Calculate Summary Statistics for SSVS-MI Results}
\usage{
\method{summary}{ssvs_mi}(object, ...)
}
\arguments{
\item{object}{An ssvs_mi result object obtained from \code{\link[=ssvs_mi]{ssvs_mi()}}}

\item{...}{Ignored}
}
\value{
A data frame with results
}
\description{
Computes summary statistics (average, minimum, and maximum) for beta coefficients, MIP and
average nonzero beta coefficients from an SSVS result object.
}
\examples{
\donttest{
data(imputed_mtcars)
outcome <- 'qsec'
predictors <- c('cyl', 'disp', 'hp', 'drat', 'wt', 'vs', 'am', 'gear', 'carb','mpg')
imputation <- '.imp'
results <- ssvs_mi(data = imputed_mtcars, y = outcome, x = predictors, imp = imputation)
summary_MI<-summary(results)
print(summary_MI)
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{plot.ssvs}
\alias{plot.ssvs}
\title{Plot results of an SSVS model}
\usage{
\method{plot}{ssvs}(x, threshold = 0.5, legend = TRUE, title = NULL, color = TRUE, ...)
}
\arguments{
\item{x}{An ssvs result object obtained from \code{\link[=ssvs]{ssvs()}}}

\item{threshold}{An MIP threshold to show on the plot, must be between 0-1.
If \code{NULL}, no threshold is used.}

\item{legend}{If \code{TRUE}, show a legend for the shapes based on the threshold.
Ignored if \code{threshold = NULL}.}

\item{title}{The title of the plot. Set to \code{NULL} to use a default title.}

\item{color}{If \code{TRUE}, the data points will be colored based on the threshold.}

\item{...}{Ignored}
}
\value{
Creates a plot of the inclusion probabilities by variable
}
\description{
Plot results of an SSVS model
}
\examples{
\donttest{
outcome <- "qsec"
predictors <- c("cyl", "disp", "hp", "drat", "wt", "vs", "am", "gear", "carb", "mpg")
results <- ssvs(x = predictors, y = outcome, data = mtcars, progress = FALSE)
plot(results)
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{dat}
\alias{dat}
\title{Example dataset for \code{ssvs} function
@format A data frame with 74 records and 76 variables}
\format{
An object of class \code{data.frame} with 74 rows and 76 columns.
}
\usage{
dat
}
\description{
Example dataset for \code{ssvs} function
@format A data frame with 74 records and 76 variables
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_MI.R
\name{print.ssvs_mi_summary}
\alias{print.ssvs_mi_summary}
\title{Print the summary of ssvs_mi}
\usage{
\method{print}{ssvs_mi_summary}(x, ...)
}
\description{
Print the summary of ssvs_mi
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/launch.R
\name{launch}
\alias{launch}
\title{Run an interactive analysis tool (Shiny app) that lets you perform SSVS in a browser}
\usage{
launch()
}
\description{
Run an interactive analysis tool (Shiny app) that lets you perform SSVS in a browser
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_MI.R
\name{plot.ssvs_mi}
\alias{plot.ssvs_mi}
\title{Plot SSVS-MI Estimates and Marginal Inclusion Probabilities (MIP)}
\usage{
\method{plot}{ssvs_mi}(
  x,
  type = "both",
  threshold = 0.5,
  legend = TRUE,
  est_title = NULL,
  mip_title = NULL,
  color = TRUE,
  ...
)
}
\arguments{
\item{x}{An ssvs result object obtained from \code{\link[=ssvs_mi]{ssvs_mi()}}}

\item{type}{Defaults to "both", can change to "estimate" or "MIP".}

\item{threshold}{A numeric value (between 0 and 1) specifying the MIP threshold to highlight significant predictors.
Defaults to 0.5.}

\item{legend}{Logical indicating whether to include a legend for the threshold. Defaults to \code{TRUE}.}

\item{est_title}{A character string specifying the plot title. Defaults to \code{"SSVS-MI estimates"}.}

\item{mip_title}{A character string specifying the plot title. Defaults to \code{"Multiple Inclusion Probability for SSVS-MI"}.}

\item{color}{Logical indicating whether to use color to highlight thresholds. Defaults to \code{TRUE}.}

\item{...}{Ignored}
}
\value{
Two \code{ggplot2} objects representing the plot of SSVS estimates and the plot of MIP with thresholds.
}
\description{
This function creates a plot of SSVS-MI estimates with minimum and maximum and a plot for marginal
inclusion probabilities (MIP) optional thresholds for highlighting significant predictors..
}
\examples{
\donttest{
data(imputed_mtcars)
outcome <- 'qsec'
predictors <- c('cyl', 'disp', 'hp', 'drat', 'wt', 'vs', 'am', 'gear', 'carb','mpg')
imputation <- '.imp'
results <- ssvs_mi(data = imputed_mtcars, y = outcome, x = predictors, imp = imputation)
plot(results)
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/imputed_mtcars.R
\docType{data}
\name{imputed_mtcars}
\alias{imputed_mtcars}
\title{Imputed mtcars Dataset}
\format{
A data frame with 160 rows and 13 variables
}
\source{
Original dataset from \code{datasets::mtcars}, with missing values introduced and imputed.
}
\usage{
imputed_mtcars
}
\description{
This dataset is a version of the \code{mtcars} dataset where random missing values
were introduced, and multiple imputation was performed using the \code{mice} package.
}
\details{
Random missingness was introduced into 10\% of the values in the original \code{mtcars} dataset.
Multiple imputation was then performed using the \code{mice} package with the following parameters:
\itemize{
\item 5 multiple imputations (\code{m = 5}).
\item 50 iterations per imputation (\code{maxit = 50}).
\item Seed set to 123 for reproducibility.
}
The dataset included here is the first completed dataset resulting from the multiple imputation process.
}
\examples{
\donttest{
data(imputed_mtcars)
head(imputed_mtcars)
}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary.R
\name{summary.ssvs}
\alias{summary.ssvs}
\title{Summarize results of an SSVS model}
\usage{
\method{summary}{ssvs}(object, interval = 0.89, threshold = 0, ordered = FALSE, ...)
}
\arguments{
\item{object}{An SSVS result object obtained from \code{\link[=ssvs]{ssvs()}}}

\item{interval}{The desired probability for the credible interval, specified as a decimal}

\item{threshold}{Minimum MIP threshold where a predictor will be shown in the output, specified as a decimal}

\item{ordered}{If \code{TRUE}, order the results based on MIP (in descending order)}

\item{...}{Ignored}
}
\value{
A dataframe with results
}
\description{
Summarize results from SSVS including marginal inclusion probabilities,
Bayesian model averaged parameter estimates, and
95\% highest posterior density credible intervals. Estimates and
credible intervals are based on standardized X variables.
}
\examples{
\donttest{
outcome <- "qsec"
predictors <- c("cyl", "disp", "hp", "drat", "wt", "vs", "am", "gear", "carb", "mpg")
results <- ssvs(data = mtcars, x = predictors, y = outcome, progress = FALSE)
summary(results, interval = 0.9, ordered = TRUE)
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary.R
\name{print.ssvs_summary}
\alias{print.ssvs_summary}
\title{Print the summary of an SSVS model}
\usage{
\method{print}{ssvs_summary}(x, ...)
}
\description{
Print the summary of an SSVS model
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/SSVS.R
\name{ssvs}
\alias{ssvs}
\title{Perform SSVS for continuous and binary outcomes}
\usage{
ssvs(
  data,
  y,
  x,
  continuous = TRUE,
  prior.probs = 0.5,
  inprob = NULL,
  force.in = NULL,
  runs = 20000,
  burn = 5000,
  a1 = 0.01,
  b1 = 0.01,
  prec.beta = 0.1,
  progress = TRUE
)
}
\arguments{
\item{data}{The dataframe used to extract predictors and response values}

\item{y}{The response variable}

\item{x}{The set of predictor variables}

\item{continuous}{If \code{TRUE}, treat the response variable as continuous. If
\code{FALSE}, treat the response variable as binary.}

\item{prior.probs}{Numeric vector or scalar specifying the prior probability
that each predictor variable is included in the model. If a scalar, the value is
replicated for all variables. If a vector, must have legnth equal to length(x).
Each value must be between 0 and 1. Setting a prior probability to 1.0 forces
that variable to always be included. The default prior inclusion probability is
.5 for all predictors. The prior inclusion probabilities will influence the
magnitude of the marginal inclusion probabilities (MIPs), but the relative pattern of
MIPs is expected to remain fairly consistent.}

\item{inprob}{\strong{Deprecated}; use \code{prior.probs} instead.
If provided, this overrides \code{prior.probs} (with a warning).}

\item{force.in}{Character vector specifying variables that should always be
included in the model. This is a convenience parameter that sets prior.probs = 1.0
for the specified variables. If both prior.probs and force.in are provided,
force.in takes precedence and will override probabilities for those variables.
Default is NULL.}

\item{runs}{Total number of iterations (including burn-in). Results are based on
the Total - Burn-in iterations.}

\item{burn}{Number of burn-in iterations. Burn-in iterations are discarded
warmup iterations used to achieve MCMC convergence. You may increase the number
of burn-in iterations if you are having convergence issues.}

\item{a1}{Prior parameter for Gamma(a,b) distribution on the precision (1/variance)
residual variance. Only used when \code{continuous = TRUE}.}

\item{b1}{Prior parameter for Gamma(a,b) distribution on the precision (1/variance)
residual variance. Only used when \code{continuous = TRUE}.}

\item{prec.beta}{Prior precision (1/variance) for beta coefficients.
Only used when \code{continuous = TRUE}.}

\item{progress}{If \code{TRUE}, show progress of the model creation. When \code{continuous = TRUE},
progress plots will be created for every 1000 iterations. When \code{continuous = FALSE},
10 progress messages will be printed.
Only used when \code{continuous = TRUE}.}
}
\value{
An ssvs object that can be used in
\code{\link[=summary.ssvs]{summary()}} or \code{\link[=plot.ssvs]{plot()}}.
}
\description{
For continuous outcomes, a basic Gibbs sampler is used. For binary
outcomes, \code{\link[BoomSpikeSlab:logit.spike]{BoomSpikeSlab::logit.spike()}} is used.
}
\examples{
\donttest{
# Example 1: Continuous response variable, uniform prior
outcome <- "qsec"
predictors <- c("cyl", "disp", "hp", "drat", "wt", "vs", "am", "gear", "carb", "mpg")
results <- ssvs(data = mtcars, x = predictors, y = outcome,
prior.probs = .5, #same for all predictors
progress = FALSE)

#' # Example 2: Continuous response variable, variable-specific priors
outcome <- "mpg"
predictors <- c("cyl", "disp", "hp", "wt")
prior.probs = c(0.7, 0.5, 0.2, 0.2) # Different prior probability for each
results <- ssvs(data = mtcars, x = predictors, y = outcome,
progress = FALSE)

# Example 3: Binary response variable
library(AER)
data(Affairs)
Affairs$hadaffair[Affairs$affairs > 0] <- 1
Affairs$hadaffair[Affairs$affairs == 0] <- 0
outcome <- "hadaffair"
predictors <- c("gender", "age", "yearsmarried", "children", "religiousness",
"education", "occupation", "rating")
results <- ssvs(data = Affairs, x = predictors, y = outcome, continuous = FALSE, progress = FALSE)

#' # Example 4: Binary response variable with forced inclusion of select predictors
library(AER)
data(Affairs)
Affairs$hadaffair[Affairs$affairs > 0] <- 1
Affairs$hadaffair[Affairs$affairs == 0] <- 0
outcome <- "hadaffair"
predictors <- c("gender", "age", "yearsmarried", "children", "religiousness",
"education", "occupation", "rating")
results <- ssvs(data = Affairs, x = predictors, y = outcome, force.in = c("children", "rating"),
continuous = FALSE, progress = FALSE)
}
}
